#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc
version:              2.17.1.1
visibility:           public
id:                   pandoc-2.17.1.1-Dbz3MosAfvx3ICqAwvi3An
key:                  pandoc-2.17.1.1-Dbz3MosAfvx3ICqAwvi3An
license:              GPL-2.0-or-later
copyright:            (c) 2006-2022 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. The formats it can handle include

    - light markup formats (many variants of Markdown,
    reStructuredText, AsciiDoc, Org-mode, Muse, Textile,
    txt2tags)
    - HTML formats (HTML 4 and 5)
    - Ebook formats (EPUB v2 and v3, FB2)
    - Documentation formats (GNU TexInfo, Haddock)
    - Roff formats (man, ms)
    - TeX formats (LaTeX, ConTeXt)
    - XML formats (DocBook 4 and 5, JATS, TEI Simple, OpenDocument)
    - Outline formats (OPML)
    - Bibliography formats (BibTeX, BibLaTeX, CSL JSON, CSL YAML)
    - Word processor formats (Docx, RTF, ODT)
    - Interactive notebook formats (Jupyter notebook ipynb)
    - Page layout formats (InDesign ICML)
    - Wiki markup formats (MediaWiki, DokuWiki, TikiWiki, TWiki,
    Vimwiki, XWiki, ZimWiki, Jira wiki, Creole)
    - Slide show formats (LaTeX Beamer, PowerPoint, Slidy,
    reveal.js, Slideous, S5, DZSlides)
    - Data formats (CSV tables)
    - PDF (via external programs such as pdflatex or wkhtmltopdf)

    Pandoc can convert mathematical content in documents
    between TeX, MathML, Word equations, roff eqn, and plain text.
    It includes a powerful system for automatic citations
    and bibliographies, and it can be customized extensively
    using templates, filters, and custom readers and writers
    written in Lua.

category:             Text
abi:                  7f96e67a7b6cadd7d36c530673529050
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify
    Text.Pandoc.Citeproc Text.Pandoc.Class Text.Pandoc.Emoji
    Text.Pandoc.Error Text.Pandoc.Extensions Text.Pandoc.Filter
    Text.Pandoc.Highlighting Text.Pandoc.ImageSize Text.Pandoc.Logging
    Text.Pandoc.Lua Text.Pandoc.MIME Text.Pandoc.MediaBag
    Text.Pandoc.Options Text.Pandoc.PDF Text.Pandoc.Parsing
    Text.Pandoc.Process Text.Pandoc.Readers Text.Pandoc.Readers.BibTeX
    Text.Pandoc.Readers.CSV Text.Pandoc.Readers.CommonMark
    Text.Pandoc.Readers.Creole Text.Pandoc.Readers.CslJson
    Text.Pandoc.Readers.Custom Text.Pandoc.Readers.DocBook
    Text.Pandoc.Readers.Docx Text.Pandoc.Readers.DokuWiki
    Text.Pandoc.Readers.EPUB Text.Pandoc.Readers.FB2
    Text.Pandoc.Readers.HTML Text.Pandoc.Readers.Haddock
    Text.Pandoc.Readers.Ipynb Text.Pandoc.Readers.JATS
    Text.Pandoc.Readers.Jira Text.Pandoc.Readers.LaTeX
    Text.Pandoc.Readers.Man Text.Pandoc.Readers.Markdown
    Text.Pandoc.Readers.MediaWiki Text.Pandoc.Readers.Muse
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.RTF
    Text.Pandoc.Readers.TWiki Text.Pandoc.Readers.Textile
    Text.Pandoc.Readers.TikiWiki Text.Pandoc.Readers.Txt2Tags
    Text.Pandoc.Readers.Vimwiki Text.Pandoc.SelfContained
    Text.Pandoc.Shared Text.Pandoc.Sources Text.Pandoc.Templates
    Text.Pandoc.UTF8 Text.Pandoc.Writers
    Text.Pandoc.Writers.AnnotatedTable Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.BibTeX Text.Pandoc.Writers.CommonMark
    Text.Pandoc.Writers.ConTeXt Text.Pandoc.Writers.CslJson
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.XWiki Text.Pandoc.Writers.ZimWiki
    Text.Pandoc.XML

hidden-modules:
    Text.Pandoc.App.CommandLineOptions Text.Pandoc.App.FormatHeuristics
    Text.Pandoc.App.Opt Text.Pandoc.App.OutputSettings
    Text.Pandoc.Class.CommonState Text.Pandoc.Class.IO
    Text.Pandoc.Class.PandocMonad Text.Pandoc.Class.PandocIO
    Text.Pandoc.Class.PandocPure Text.Pandoc.Class.Sandbox
    Text.Pandoc.Filter.Environment Text.Pandoc.Filter.JSON
    Text.Pandoc.Filter.Lua Text.Pandoc.Filter.Path
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Fields Text.Pandoc.Readers.HTML.Parsing
    Text.Pandoc.Readers.HTML.Table
    Text.Pandoc.Readers.HTML.TagCategories
    Text.Pandoc.Readers.HTML.Types Text.Pandoc.Readers.LaTeX.Inline
    Text.Pandoc.Readers.LaTeX.Citation Text.Pandoc.Readers.LaTeX.Lang
    Text.Pandoc.Readers.LaTeX.Macro Text.Pandoc.Readers.LaTeX.Math
    Text.Pandoc.Readers.LaTeX.Parsing Text.Pandoc.Readers.LaTeX.SIunitx
    Text.Pandoc.Readers.LaTeX.Table Text.Pandoc.Readers.LaTeX.Types
    Text.Pandoc.Readers.Odt.Base Text.Pandoc.Readers.Odt.Namespaces
    Text.Pandoc.Readers.Odt.StyleReader
    Text.Pandoc.Readers.Odt.ContentReader
    Text.Pandoc.Readers.Odt.Generic.Fallible
    Text.Pandoc.Readers.Odt.Generic.SetMap
    Text.Pandoc.Readers.Odt.Generic.Utils
    Text.Pandoc.Readers.Odt.Generic.Namespaces
    Text.Pandoc.Readers.Odt.Generic.XMLConverter
    Text.Pandoc.Readers.Odt.Arrows.State
    Text.Pandoc.Readers.Odt.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Docx.Table Text.Pandoc.Writers.Docx.Types
    Text.Pandoc.Writers.GridTable Text.Pandoc.Writers.JATS.References
    Text.Pandoc.Writers.JATS.Table Text.Pandoc.Writers.JATS.Types
    Text.Pandoc.Writers.LaTeX.Caption Text.Pandoc.Writers.LaTeX.Notes
    Text.Pandoc.Writers.LaTeX.Table Text.Pandoc.Writers.LaTeX.Lang
    Text.Pandoc.Writers.LaTeX.Types Text.Pandoc.Writers.LaTeX.Citation
    Text.Pandoc.Writers.LaTeX.Util Text.Pandoc.Writers.Markdown.Types
    Text.Pandoc.Writers.Markdown.Inline Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Blaze
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output
    Text.Pandoc.Lua.ErrorConversion Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.CommonState Text.Pandoc.Lua.Marshal.Context
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Orphans Text.Pandoc.Lua.Packages
    Text.Pandoc.Lua.PandocLua Text.Pandoc.XML.Light
    Text.Pandoc.XML.Light.Types Text.Pandoc.XML.Light.Proc
    Text.Pandoc.XML.Light.Output Text.Pandoc.Network.HTTP
    Text.Pandoc.CSS Text.Pandoc.CSV Text.Pandoc.RoffChar
    Text.Pandoc.UUID Text.Pandoc.Translations Text.Pandoc.Slides
    Text.Pandoc.Image Text.Pandoc.Citeproc.BibTeX
    Text.Pandoc.Citeproc.CslJson Text.Pandoc.Citeproc.Data
    Text.Pandoc.Citeproc.Locator Text.Pandoc.Citeproc.MetaValue
    Text.Pandoc.Citeproc.Util Paths_pandoc

import-dirs:          /usr/lib/ghc-9.0.2/site-local/pandoc-2.17.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pandoc-2.17.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc
hs-libraries:         HSpandoc-2.17.1.1-Dbz3MosAfvx3ICqAwvi3An
depends:
    Glob-0.10.2-4sSupuhkxx8AtMxZQBpWpP
    JuicyPixels-3.3.7-CwjZP5kwkgmHkkOv0XQFME
    SHA-1.6.4.4-1UNVNO3JXJdDGqRoMkntZx
    aeson-1.5.6.0-GZUW0RX6wR0GNyId2zbUZx
    aeson-pretty-0.8.9-JgwmWNQqkZ88vmb6GH5qjO array-0.5.4.0
    attoparsec-0.14.4-JmvG4Wvx4EM5mKBIEGEaPX base-4.15.1.0
    base64-bytestring-1.2.1.0-GmQybdYprrT5099ebyH5id binary-0.8.8.0
    blaze-html-0.9.1.2-FurepHreZWz84uhLaEiEvd
    blaze-markup-0.8.2.8-2xIXHgE7ZN5Kvv24S5OwO bytestring-0.10.12.1
    case-insensitive-1.2.1.0-APguMq08drVChfWtieJFqR
    citeproc-0.6.0.1-DpYIURk6B1bKITrila695M
    commonmark-0.2.1.1-7h9kvu3cpSBAqD4z2Mrsv7
    commonmark-extensions-0.2.3-E2llPMms60G2PXiz1iWhm
    commonmark-pandoc-0.2.1.2-IDUi0QcsBOcJoHT2XzbCdx
    connection-0.3.1-JVjKQzsxxkL2MRvwzbb4MW containers-0.6.4.1
    data-default-0.7.1.1-IhQr772Rp9DBpduGZCnNjb deepseq-1.4.5.0
    directory-1.3.6.2 doclayout-0.3.1.1-3IUgYlrv7Pg7jDMAJzbI9N
    doctemplates-0.10.0.1-GIpTuJrhyc36pFCkX9v9xy
    emojis-0.1.2-35b0RtOoiMtDRp9GEExKt6 exceptions-0.10.4
    file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn filepath-1.4.2.1
    haddock-library-1.10.0-6HQQrtCkN6s9XNjvo0pqry
    hslua-2.1.0-AAB8D6xBUTF6D5qVtGhFlJ
    hslua-aeson-2.1.0-GQmzxLAtDsfEsPPmS0zKsY
    hslua-marshalling-2.1.0-2zNQAwLI8YxHgfMiPmX9JY
    hslua-module-path-1.0.1-IFkY8DMM8HX96Bv2kPXdQl
    hslua-module-system-1.0.1-90LvDUecq1jpkSFDzztqD
    hslua-module-text-1.0.1-8rfuuQxULF2BnQzPM8Uqkb
    hslua-module-version-1.0.1-6JFJoqWyKv7KwlPC7LdAiO
    http-client-0.7.11-DoT8EqSk6Ca1O2bv9Cs89J
    http-client-tls-0.3.6.1-3O0oDS2oezT8WjK3sboemw
    http-types-0.12.3-Ea7yOEbOLw3Rgx6iPEaWk
    ipynb-0.2-CnlUjUjpP7LEAyAyOacpPS
    jira-wiki-markup-1.4.0-8NLCtH98Y4a3miZkZH2Qeg
    lpeg-1.0.2-5OyLEp8k2t47va5wqPImOq mtl-2.2.2
    network-3.1.2.7-CS681TPv1I76Ct75uHBcbk
    network-uri-2.6.4.1-LX64IFesN4tEtd5HBD7ndF
    pandoc-lua-marshal-0.1.5.1-2MwNMitNTWrB1HWpW0KqRt
    pandoc-types-1.22.2-4J56yG1YCQRJktXCxCbDiy parsec-3.1.14.0
    pretty-1.1.3.6 pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    process-1.6.13.2 random-1.2.1.1-5iWH2ycrnoQ5ZYD66L7QAJ
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    scientific-0.3.7.0-BGDOHpeWZcM6hFLsiwwQPU
    skylighting-0.12.3-L8gaem3COTa4x51DYylJIs
    skylighting-core-0.12.3-CosA8NIiq26uQpaBpaAI1
    split-0.2.3.4-Fg50BenITmx17h2SSO27kp
    syb-0.7.2.1-6CQDGohRFIeFi4mwZMmgcI
    tagsoup-0.14.8-GKC1pKqGz7ACsSW6E8kBlE
    temporary-1.3-9oxiXZ267LZ1qRPbSjfFD6
    texmath-0.12.5-KbjWdAD6IKFIj2qjKLRAOI text-1.2.5.0
    text-conversions-0.3.1.1-IryUcwbHBCCIsDOOOsVy35 time-1.9.3
    unicode-collation-0.1.3.2-AORFPxGfmyh35rwKEdunUp
    unicode-transforms-0.4.0.1-CS8JIVlEIr236To0JnBYQ unix-2.7.2.2
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM
    xml-conduit-1.9.1.1-ebAsdbhKZrKfyJhWX8VkP
    yaml-0.11.8.0-2gjMXntCL4H8yjm4kOg83o
    zip-archive-0.4.2.1-lv97w3uCYbABpDlLrOSRa
    zlib-0.6.3.0-21v2LROaEjkDwSJfgcvMgm

haddock-interfaces:   /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

